@@ -11,16 +11,18 @@ def test_diagram_attributes():
     eq_(160, diagram.node_height)
     eq_(32, diagram.span_width)
     eq_(32, diagram.span_height)
-    eq_(16, diagram.default_fontsize)
     eq_((128, 128, 128), diagram.linecolor)       # gray
     eq_('diamond', diagram.nodes[0].shape)
     eq_((255, 0, 0), diagram.nodes[0].color)      # red
     eq_((0, 128, 0), diagram.nodes[0].textcolor)  # green
+    eq_(16, diagram.nodes[0].fontsize)
     eq_((0, 0, 255), diagram.nodes[1].color)      # blue
     eq_((0, 128, 0), diagram.nodes[1].textcolor)  # green
+    eq_(16, diagram.nodes[1].fontsize)
 
     eq_((128, 128, 128), diagram.edges[0].color)  # gray
     eq_((0, 128, 0), diagram.edges[0].textcolor)  # green
+    eq_(16, diagram.edges[0].fontsize)
 
 
 def test_circular_ref_to_root_diagram():
@@ -129,6 +131,14 @@ def test_rhombus_relation_height_diagram():
     __validate_node_attributes('rhombus_relation_height.diag', xy=positions)
 
 
+def test_non_rhombus_relation_height_diagram():
+    positions = {'A': (0, 0), 'B': (1, 0), 'C': (2, 0), 'D': (0, 1),
+                 'E': (0, 2), 'F': (1, 2), 'G': (1, 3), 'H': (2, 3),
+                 'I': (2, 4), 'J': (1, 5), 'K': (2, 5), 'Z': (0, 6)}
+    __validate_node_attributes('non_rhombus_relation_height.diag',
+                               xy=positions)
+
+
 def test_define_class_diagram():
     colors = {'A': (255, 0, 0), 'B': (255, 255, 255), 'C': (255, 255, 255)}
     styles = {'A': 'dashed', 'B': None, 'C': None}
