@@ -35,6 +35,11 @@ def test_unknown_node_style_diagram():
     diagram = __build_diagram('errors/unknown_node_style.diag')
 
 
+@raises(AttributeError)
+def test_unknown_node_class_diagram():
+    diagram = __build_diagram('errors/unknown_node_class.diag')
+
+
 @raises(AttributeError)
 def test_unknown_edge_dir_diagram():
     diagram = __build_diagram('errors/unknown_edge_dir.diag')
@@ -50,11 +55,36 @@ def test_unknown_edge_hstyle_diagram():
     diagram = __build_diagram('errors/unknown_edge_hstyle.diag')
 
 
+@raises(AttributeError)
+def test_unknown_edge_class_diagram():
+    diagram = __build_diagram('errors/unknown_edge_class.diag')
+
+
+@raises(AttributeError)
+def test_unknown_group_shape_diagram():
+    diagram = __build_diagram('errors/unknown_group_shape.diag')
+
+
+@raises(AttributeError)
+def test_unknown_group_class_diagram():
+    diagram = __build_diagram('errors/unknown_group_class.diag')
+
+
+@raises(AttributeError)
+def test_unknown_group_orientation_diagram():
+    diagram = __build_diagram('errors/unknown_group_orientation.diag')
+
+
 @raises(RuntimeError)
 def test_belongs_to_two_groups_diagram():
     diagram = __build_diagram('errors/belongs_to_two_groups.diag')
 
 
+@raises(AttributeError)
+def test_unknown_plugin_diagram():
+    diagram = __build_diagram('errors/unknown_plugin.diag')
+
+
 @raises(ParseException)
 def test_node_follows_group_diagram():
     diagram = __build_diagram('errors/node_follows_group.diag')
